;; Generated package description from plz.el  -*- no-byte-compile: t -*-
(define-package "plz" "0.7" "HTTP library" '((emacs "26.3")) :commit "70ebd6edea2b5c376776cd747bc378b07f0e6646" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("comm" "network" "http") :url "https://github.com/alphapapa/plz.el")
